@@ -59,19 +59,12 @@ int main(int argc, char *argv[])
     }
 
     QQmlApplicationEngine engine(&qApplication);
-    const QUrl url(QStringLiteral("qrc:/qt/qml/org/kde/haruna/qml/main.qml"));
-    auto onObjectCreated = [url](const QObject *obj, const QUrl &objUrl) {
-        if (!obj && url == objUrl) {
-            QCoreApplication::exit(-1);
-        }
-    };
-    QObject::connect(&engine, &QQmlApplicationEngine::objectCreated, &qApplication, onObjectCreated, Qt::QueuedConnection);
     engine.addImageProvider(QStringLiteral("thumbnail"), new ThumbnailImageProvider());
     engine.rootContext()->setContextProperty(QStringLiteral("app"), Application::instance());
     engine.rootContext()->setContextProperty(QStringLiteral("appActions"), new QQmlPropertyMap);
     engine.rootContext()->setContextObject(new KLocalizedContext(Application::instance()));
     engine.rootContext()->setContextProperty(QStringLiteral("harunaAboutData"), QVariant::fromValue(KAboutData::applicationData()));
-    engine.load(url);
+    engine.loadFromModule("org.kde.haruna", "Main");
 
     application->setQmlEngine(&engine);
 
