@@ -22,7 +22,6 @@
 #include "chaptersmodel.h"
 #include "generalsettings.h"
 #include "global.h"
-#include "informationsettings.h"
 #include "mpvproperties.h"
 #include "playbacksettings.h"
 #include "playlistmodel.h"
@@ -65,6 +64,7 @@ MpvItem::MpvItem(QQuickItem *parent)
     Q_EMIT observeProperty(MpvProperties::self()->SecondarySubtitleId, MPV_FORMAT_INT64);
     Q_EMIT observeProperty(MpvProperties::self()->Chapter, MPV_FORMAT_INT64);
     Q_EMIT observeProperty(MpvProperties::self()->ChapterList, MPV_FORMAT_NODE);
+    Q_EMIT observeProperty(MpvProperties::self()->TracksCount, MPV_FORMAT_NODE);
 
     initProperties();
     setupConnections();
@@ -390,6 +390,10 @@ void MpvItem::onPropertyChanged(const QString &property, const QVariant &value)
     } else if (property == MpvProperties::self()->Height) {
         m_videoHeight = value.toInt();
         Q_EMIT videoHeightChanged();
+
+    } else if (property == MpvProperties::self()->TracksCount) {
+        loadTracks(getProperty(MpvProperties::self()->TrackList).toList());
+        Q_EMIT videoHeightChanged();
     }
 }
 
@@ -488,6 +492,15 @@ void MpvItem::onAsyncReply(const QVariant &data, mpv_event event)
     }
     case AsyncIds::VideoId: {
         if (!data.toBool()) {
+            // there's no video track
+            // either because the file is an audio file or the video track can't be decoded
+            auto mimeType = Application::mimeType(currentUrl());
+            if (mimeType.startsWith(u"video/"_qs)) {
+                auto errMsg = i18nc("Error message when video can't be decoded/played",
+                                    "No video track detected, most likely the video track can't be decoded/played due to missing codecs");
+                Q_EMIT Application::instance()->error(errMsg);
+                break;
+            }
             Q_EMIT command(QStringList{QStringLiteral("video-add"), VideoSettings::defaultCover()});
         }
         break;
