@@ -31,18 +31,20 @@ Worker *Worker::instance()
 
 void Worker::getMetaData(int index, const QString &path)
 {
+    using namespace KFileMetaData;
+
     auto url = QUrl::fromUserInput(path);
     if (url.scheme() != QStringLiteral("file")) {
         return;
     }
     QString mimeType = Application::mimeType(url);
-    KFileMetaData::ExtractorCollection exCol;
-    QList<KFileMetaData::Extractor *> extractors = exCol.fetchExtractors(mimeType);
-    KFileMetaData::SimpleExtractionResult result(path, mimeType, KFileMetaData::ExtractionResult::ExtractMetaData);
+    ExtractorCollection exCol;
+    QList<Extractor *> extractors = exCol.fetchExtractors(mimeType);
+    SimpleExtractionResult result(url.toLocalFile(), mimeType, ExtractionResult::ExtractMetaData);
     if (extractors.size() == 0) {
         return;
     }
-    KFileMetaData::Extractor *ex = extractors.first();
+    Extractor *ex = extractors.first();
     ex->extract(&result);
 
     auto properties = result.properties();
